require 'spec_helper'

describe NamedSeguesController, type: :controller do

  after(:each) do
    session[:action_segues] = nil
  end

  describe "selecting a particular segue" do
    it "should store the segue on the first page" do
      get :segue_start_page
      expect(session[:action_segues][:named_segue].params).to eq({ "controller" => "named_segues", "action" => "segue_start_page" })
    end

    it "should redirect to the segue entry point" do
      get :segue_start_page
      get :normal_page
      get :segue_complete_page
      expect(response).to redirect_to(segue_start_page_named_segue_path)
    end

    it "should redirect to the fallback if the segue doesn't exist" do
      get :second_segue_start_page
      get :segue_complete_page
      expect(response).to redirect_to(normal_page_named_segue_path)
    end
  end

  describe "completing any segue" do
    it "should complete the most resent segue in the stack" do
      get :segue_start_page
      get :second_segue_start_page
      get :segue_complete_last_page
      expect(response).to redirect_to(second_segue_start_page_named_segue_path)
    end

    it "should remove the segue after it is completed" do
      get :second_segue_start_page
      get :segue_complete_last_page
      expect(session[:action_segues]).to eq({})
    end

    it "should redirect to the fallback if the stack is empty" do
      get :segue_complete_last_page
      expect(response).to redirect_to(normal_page_named_segue_path)
    end
  end

  describe "cleaning up" do
    it "should remove the segue from the stack after it is completed" do
      get :segue_start_page
      get :normal_page
      get :segue_complete_page
      expect(session[:action_segues]).to eq({})
    end

    it "should be possible to remove the segue" do
      get :segue_start_page
      get :segue_clear_page
      get :segue_complete_page
      expect(response).to redirect_to(normal_page_named_segue_path)
    end
  end

end
